Rename drm_sysfs_connector_status_event() to
drm_sysfs_connector_property_event(). Indeed, "status" is a bit
vague: it can easily be confused with the connected/disconnected
status of the connector. This function has nothing to do with
connected/disconnected: it merely sends a notification that a
connector's property has changed (e.g. HDCP, privacy screen, etc).

Signed-off-by: Simon Ser <cont...@emersion.fr>
Cc: Manasi Navare <navareman...@chromium.org>
Cc: Sam Ravnborg <s...@ravnborg.org>
Cc: Harry Wentland <harry.wentl...@amd.com>
Cc: Daniel Vetter <dan...@ffwll.ch>
---
 drivers/gpu/drm/display/drm_hdcp_helper.c |  4 ++--
 drivers/gpu/drm/drm_connector.c           |  8 ++++----
 drivers/gpu/drm/drm_sysfs.c               | 23 +++++++++++++----------
 include/drm/drm_sysfs.h                   |  4 ++--
 4 files changed, 21 insertions(+), 18 deletions(-)

diff --git a/drivers/gpu/drm/display/drm_hdcp_helper.c 
b/drivers/gpu/drm/display/drm_hdcp_helper.c
index e78999c72bd7..a3f0e6d96105 100644
--- a/drivers/gpu/drm/display/drm_hdcp_helper.c
+++ b/drivers/gpu/drm/display/drm_hdcp_helper.c
@@ -415,7 +415,7 @@ void drm_hdcp_update_content_protection(struct 
drm_connector *connector,
                return;
 
        state->content_protection = val;
-       drm_sysfs_connector_status_event(connector,
-                                dev->mode_config.content_protection_property);
+       drm_sysfs_connector_property_event(connector,
+                                          
dev->mode_config.content_protection_property);
 }
 EXPORT_SYMBOL(drm_hdcp_update_content_protection);
diff --git a/drivers/gpu/drm/drm_connector.c b/drivers/gpu/drm/drm_connector.c
index 3ed4cfcb350c..bf8371dc2a61 100644
--- a/drivers/gpu/drm/drm_connector.c
+++ b/drivers/gpu/drm/drm_connector.c
@@ -2730,10 +2730,10 @@ static int drm_connector_privacy_screen_notifier(
        drm_connector_update_privacy_screen_properties(connector, true);
        drm_modeset_unlock(&dev->mode_config.connection_mutex);
 
-       drm_sysfs_connector_status_event(connector,
-                               connector->privacy_screen_sw_state_property);
-       drm_sysfs_connector_status_event(connector,
-                               connector->privacy_screen_hw_state_property);
+       drm_sysfs_connector_property_event(connector,
+                                          
connector->privacy_screen_sw_state_property);
+       drm_sysfs_connector_property_event(connector,
+                                          
connector->privacy_screen_hw_state_property);
 
        return NOTIFY_DONE;
 }
diff --git a/include/drm/drm_sysfs.h b/include/drm/drm_sysfs.h
index 6273cac44e47..96a5d858404b 100644
--- a/include/drm/drm_sysfs.h
+++ b/include/drm/drm_sysfs.h
@@ -12,6 +12,6 @@ void drm_class_device_unregister(struct device *dev);
 
 void drm_sysfs_hotplug_event(struct drm_device *dev);
 void drm_sysfs_connector_hotplug_event(struct drm_connector *connector);
-void drm_sysfs_connector_status_event(struct drm_connector *connector,
-                                     struct drm_property *property);
+void drm_sysfs_connector_property_event(struct drm_connector *connector,
+                                       struct drm_property *property);
 #endif
diff --git a/drivers/gpu/drm/drm_sysfs.c b/drivers/gpu/drm/drm_sysfs.c
index f62767ff34b2..b169b3e44a92 100644
--- a/drivers/gpu/drm/drm_sysfs.c
+++ b/drivers/gpu/drm/drm_sysfs.c
@@ -487,17 +487,17 @@ void drm_sysfs_connector_hotplug_event(struct 
drm_connector *connector)
 EXPORT_SYMBOL(drm_sysfs_connector_hotplug_event);
 
 /**
  * drm_sysfs_connector_status_event - generate a DRM uevent for connector
  * property status change
  * @connector: connector on which property status changed
  * @property: connector property whose status changed.
  *
- * Send a uevent for the DRM device specified by @dev.  Currently we
+ * Send a uevent for the specified DRM connector and property.  Currently we
  * set HOTPLUG=1 and connector id along with the attached property id
- * related to the status change.
+ * related to the change.
  */
-void drm_sysfs_connector_status_event(struct drm_connector *connector,
-                                     struct drm_property *property)
+void drm_sysfs_connector_property_event(struct drm_connector *connector,
+                                       struct drm_property *property)
 {
        struct drm_device *dev = connector->dev;
        char hotplug_str[] = "HOTPLUG=1", conn_id[21], prop_id[21];
@@ -511,11 +511,14 @@ void drm_sysfs_connector_status_event(struct 
drm_connector *connector,
        snprintf(prop_id, ARRAY_SIZE(prop_id),
                 "PROPERTY=%u", property->base.id);
 
-       DRM_DEBUG("generating connector status event\n");
+       drm_dbg_kms(connector->dev,
+                   "[CONNECTOR:%d:%s] generating connector property event for 
[PROP:%d:%s]\n",
+                   connector->base.id, connector->name,
+                   property->base.id, property->name);
 
        kobject_uevent_env(&dev->primary->kdev->kobj, KOBJ_CHANGE, envp);
 }
-EXPORT_SYMBOL(drm_sysfs_connector_status_event);
+EXPORT_SYMBOL(drm_sysfs_connector_property_event);
 
 struct device *drm_sysfs_minor_alloc(struct drm_minor *minor)
 {
@@ -487,17 +487,17 @@ void drm_sysfs_connector_hotplug_event(struct 
 
 /**
- * drm_sysfs_connector_status_event - generate a DRM uevent for connector
- * property status change
- * @connector: connector on which property status changed
- * @property: connector property whose status changed.
+ * drm_sysfs_connector_property_event - generate a DRM uevent for connector
+ * property change
+ * @connector: connector on which property changed
+ * @property: connector property which has changed.
  *
-- 
2.41.0


Reply via email to